@@ -9,6 +9,7 @@ class BaseMessage:
     Abstract class for shared functionality between Messages and
     Acknowledgement responses.
     """
+
     def __init__(self,
                  channel: Optional[str] = None,
                  text: Optional[str] = "",
@@ -43,6 +44,9 @@ class BaseMessage:
             message["text"] = self.text
         return message
 
+    def to_dict(self) -> Dict[str, Any]:
+        return self._resolve()
+
     def json(self) -> str:
         return dumps(self._resolve(), indent=4)
 
@@ -61,6 +65,7 @@ class Message(BaseMessage):
     A Slack message object that can be converted to a JSON string for use with
     the Slack message API.
     """
+
     def __init__(self,
                  channel: str,
                  text: Optional[str] = "",
@@ -75,6 +80,7 @@ class MessageResponse(BaseMessage):
     """
     A required, immediate response that confirms your app received the payload.
     """
+
     def __init__(self,
                  text: Optional[str] = "",
                  blocks: Optional[Union[List[Block], Block]] = None,
@@ -92,6 +98,8 @@ class MessageResponse(BaseMessage):
         self.ephemeral = ephemeral
 
     def _resolve(self) -> Dict[str, Any]:
-        return {**super()._resolve(),
-                "replace_original": self.replace_original,
-                "ephemeral": self.ephemeral}
+        result = {**super()._resolve(),
+                  "replace_original": self.replace_original}
+        if self.ephemeral:
+            result["response_type"] = "ephemeral"
+        return result
